import os
import json
import requests
import tempfile

from wedoc.api import document
from wedoc.api import spreadsheet


class WedocClient:
    doc = document.Document()
    wb = spreadsheet.Spreadsheet()

    def __init__(self, corpid, corpsecret) -> None:
        self.base_url = "https://qyapi.weixin.qq.com/cgi-bin"
        self.corpid = corpid
        self.corpsecret = corpsecret
        self.access_token = self.get_local_session()

    def get_local_session(self):
        """创建企业微信应用 access_token 缓存"""
        tmp_path = tempfile.gettempdir()
        wework_app_token_path = os.path.join(tmp_path, "wework_app_token")

        if not os.path.exists(wework_app_token_path):
            access_token = self.get_access_token().get("access_token")
            token_dict = {"access_token": access_token}
            with open(wework_app_token_path, "w") as f:
                json.dump(token_dict, f)
        with open(wework_app_token_path) as f:
            token_dict = json.load(f)
            if token_dict.get("access_token"):
                return token_dict.get("access_token")

    def get_access_token(self):
        """获取企业微信应用的 access_token"""
        url = f"{self.base_url}/gettoken?corpid={self.corpid}&corpsecret={self.corpsecret}"
        payload = {}
        headers = {}
        response = requests.request("GET", url, headers=headers, data=payload)
        return response.json()

    def request(self, method, api, params=None, pyload={}):
        """发送请求"""
        url = f"{self.base_url}{api}?access_token={self.access_token}"
        headers = {"Content-Type": "application/json"}
        res = requests.request(
            method, url, params=params, data=json.dumps(pyload), headers=headers
        )
        return res.json()


if __name__ == "__main__":
    pass



class Document:
    def __init__(self) -> None:
        pass

    def create_doc(self):
        """创建文档"""
        api = "/wedoc/create_doc"
        pyload = {
            "spaceid": "SPACEID",
            "fatherid": "FATHERID",
            "doc_type": "DOC_TYPE",
            "doc_name": "DOC_NAME",
            "admin_users": ["USERID1", "USERID2", "USERID3"],
        }

        res = self.request("post", api, pyload)
        return res

    def rename_doc(self, docid, new_name):
        """重命名文档"""
        api = "/wedoc/rename_doc"
        pyload = {"docid": docid, "new_name": new_name}
        res = self.request("post", api, pyload)
        return res

    def del_doc(self, docid):
        """删除文档"""
        api = "/wedoc/del_doc"
        pyload = {"docid": docid}
        res = self.request("post", api, pyload)
        return res

    def get_doc_base_info(self, docid):
        """获取文档基础信息"""
        api = "/wedoc/get_doc_base_info"
        pyload = {"docid": docid}
        res = self.request("post", api, pyload)
        return res
